@@ -2,13 +2,16 @@
 BEGIN { $diagnostics::PRETTY = 1 }
 
 package Pat::Logger;
-our $VERSION = '2.0';
+our $VERSION = '3.1';
+
+use lib qw( /Eng );
 
 use strict;
 use diagnostics;
 use Fcntl ':flock';
+use Pat::General;
 
-use fields qw ( Debug_Log First_Message Separator );
+use fields qw ( Debug_Log First_Message Separator time_pack sub_pack line_pack msg_pack );
 
 
 # ------------------------
@@ -27,7 +30,17 @@ sub _get_debug_params();
 
 
 # Global variables:
-my $separator = "\n\n" . scalar ('-' x 152) . "\n\n";
+my $time_pack = 'A22';
+my $sub_pack  = 'A29';
+my $line_pack = 'A10';
+my $msg_pack  = 'A99';
+
+my $separator = "\n";
+$separator  = '-' x substr $time_pack, 1;
+$separator .= '-' x substr $sub_pack , 1;
+$separator .= '-' x substr $line_pack, 1;
+$separator .= '-' x substr $msg_pack , 1;
+$separator .= "\n";
 
 
 # -----------------------------------------------------------------
@@ -55,8 +68,11 @@ sub new($)
     $self->{Debug_Log}	    = $debug_file;
     $self->{First_Message}  = 1;
     $self->{Separator}	    = $separator;
-   
-
+    
+    $self->{time_pack} = $time_pack;
+    $self->{sub_pack}  = $sub_pack;
+    $self->{line_pack} = $line_pack;
+    $self->{msg_pack}  = $msg_pack;
 
     return $self;
 }
@@ -85,7 +101,11 @@ sub new_stdout()
     $self->{First_Message} = 1;
     $self->{Separator}	   = $separator;
     
-
+    $self->{time_pack} = $time_pack;
+    $self->{sub_pack}  = $sub_pack;
+    $self->{line_pack} = $line_pack;
+    $self->{msg_pack}  = $msg_pack; 
+    
     return $self;    
 }
 
@@ -101,8 +121,8 @@ sub new_stdout()
 # -----------------------------------------------------------------
 sub debug_message($)
 {  
-    my ($self, $message) = @_;
-    my ($package, $sub, $line) ;
+    my ( $self, $message ) = @_;
+    my ( $package, $sub, $line, $time ) ;
     my $debug_message = '';
     my $rc;
 
@@ -116,14 +136,14 @@ sub debug_message($)
     chomp $message; #Just in case;        
 
     # In this part we gather all the information relevant for this debug message:
-    ($package, $sub, $line) = $self->_get_debug_params();  
+    ( $package, $sub, $line, $time ) = $self->_get_debug_params();  
 
 
     # It's the first time we print a message, so let's create the headers:
     $debug_message  = $self->_get_header() if $self->{First_Message};
 
     
-    $debug_message .= $self->_pack_str( $package, $sub, $line, $message );
+    $debug_message .= $self->_pack_str( $time, $package, $sub, $line, $message );
     
     
     $self->_print_to_file( $debug_message ) if defined $self->{Debug_Log};
@@ -169,15 +189,20 @@ sub _get_header()
     my $self = shift;
 
     $self->{First_Message} = 0;
+ 
+    
+    my $headers = $self->{Separator};
+    
+    $headers .= pack $self->{time_pack}, ' TIME';
+    $headers .= pack $self->{sub_pack}, 'METHOD';
+    $headers .= pack $self->{line_pack}, 'LINE';
+    $headers .= pack $self->{msg_pack}, 'MESSAGE';
+    $headers .= "\n";
+    
+    $headers .= $self->{Separator};
     
-    my $headers = "
---------------------------------------------------------------------------------------------------------------------------------------------------------
- PACKAGE	METHOD		    	     LINE      MESSAGE
---------------------------------------------------------------------------------------------------------------------------------------------------------\n\n";
-
     return $headers;
 }
-     
 
 
 sub separate()
@@ -197,18 +222,18 @@ sub separate()
 sub _pack_str( $$$$ )
 {
     my $self = shift;
-    my ( $package, $sub, $line, $message ) = @_;
+    my ( $time, $package, $sub, $line, $message ) = @_;
     my $pid;
     my $result = '';
     
  
-    #print "I got $package, $sub, $line, $message\n";
-   
-    $result  = pack ( "A16", " $package" );
-    $result .= pack ( "A29", $sub );
-    $result .= pack ( "A10", $line );
-    $result .= pack ( "A98", $message );
-    $result  .= "\n";
+    #print "I got $time, $package, $sub, $line, $message\n";
+
+    $result  = pack ( $self->{time_pack}, " $time" );
+    $result .= pack ( $self->{sub_pack} , $package .'::' . $sub );
+    $result .= pack ( $self->{line_pack}, $line );
+    $result .= pack ( $self->{msg_pack} , $message );
+    $result .= "\n";
     
     return $result;
     
@@ -225,7 +250,10 @@ sub _pack_str( $$$$ )
 sub _get_debug_params()
 {
     my $self = shift;
-    my ($package, $sub, $line);
+    my ( $package, $sub, $line, $time );
+    
+    $time = Pat::General::eval_time();
+    
     my @caller_param_1 = caller(1);
     my @caller_param_2 = caller(2);
 
@@ -250,7 +278,7 @@ sub _get_debug_params()
     $sub = $subroutine[ $#subroutine ];
 
 
-    return ($package, $sub, $line);
+    return ( $package, $sub, $line, $time );
 }
 
 
@@ -283,6 +311,7 @@ __END__
 
     $logger->debug_message ( "Logger will tell you the package, subroutine and line number" );
     $logger->debug_message ( 'your debug message originated from' );
+    $logger->debug_message ( "This line will blink in RED!", 'ERROR' ); # A second argument wil make the message appear in blinking red color.
 
 =over
 
@@ -293,7 +322,7 @@ __END__
 =head1
 
     use Pat::Logger;
-    eval { $logger = new_stdout Pat::Logger() };
+    eval { $logger = new Pat::Logger() };
     die $@ if $@;
 
     $logger->debug_message ( "This line will go to STDERR only" );
@@ -313,33 +342,32 @@ __END__
     Not only you want to see the messages on screen, you want to have them in a local file as well.
     Logger does just that.
 
-    There are two working modes for Logger, each one has it's own constructor:
-
+    There are two working modes for Logger:
     (1) Debugging to STDERR+file.
     (2) Debugging to STDERR only.
 
 =over
 
-=item  * B<new($)>
+=item  * B<new($)> ( With or without parameter )
 
-    This constructor expects a file name to output all message to.
+    This constructor can receive a file name to output all message to.
     Upon success, a blessed hash reference will be returned.
     Upon failure the method dies, and $@ will hold the error message.
 
+    If a parameter is not passed, Logger will output all the debug messages to STDERR.
 
-=item * B<new_stdout()>
 
-    All debug messages will be sent to STDERR solemly.
-    Upon success, a blessed hash reference will be returned.
-    Upon failure the method dies, and $@ will hold the error message.
-    
+=item * B<debug_message($$)>
 
-=item * B<debug_message($)>
+    This method takes two argument - the debug message you wish to log and it's severity.
 
-    This method takes one argument - the debug message you wish to log.
+    For example:
+    $logger->debug_message ( "This is a regular message" );
+    $logger->debug_message ( "I cought an exception: $@", 'ERROR' ); # This message will stand out from the others,
+								     # As it will blink in red color.  
     Upon success - the method returns 1.
     Upon failre  - the method returns 0.
-    
+
     The Logger object does all the work behind the scenes:
     (1) Grab the package, subroutine name and line number which the message originated from.
     (2) Create a nice format with the parameters aforementioned.
@@ -348,11 +376,26 @@ __END__
 =item * B<separate()>
 
     You may wish to create visual separation between messages.
-    When you invoke separate(), a line consistant of 152 x '-' will be outputed.
-
     This length is coherent with the length of the format.
  
 
+=head1 CONTROLING LENGTHS
+
+    It is possible to control the space of each field ( Time, Message, etc ).
+    At the top of the module, you need to adjust the gloabl Variables' value.
+
+    For example, if you wish to donate 50 characters to the message itself,
+    simply modify the $msg_pack from 'A99' to 'a50'. The same goes for the other fields.
+
+    the module automatically adjusts the header and separation when you modify the length of the fields.
+
+    # Global variables:
+    my $time_pack = 'A22';	# Control length of time field ( No real need to do so - It's optimized ).
+    my $sub_pack  = 'A29';	# Control length of subroutine field. 
+    my $line_pack = 'A10';	# Control length of line number fiekd.
+    my $msg_pack  = 'A99';	# Control length of message field.
+
+
 =head1 BUGS
 
     None at the moment. 
