@@ -1,3 +1,5 @@
+
+
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
 
@@ -8,7 +10,9 @@
 
 BEGIN { $| = 1; print "1..1\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use Logger;
+use Pat::Logger;
+use Pat::General;
+
 $loaded = 1;
 print "ok 1\n";
 
